import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**首页-table列表*/
export const columns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'taskName',
    width: 120
  },
  {
    title: '启动时间',
    dataIndex: 'startTime',
    width: 120
  },
  {
    title: '源端',
    dataIndex: 'source',
    width: 120
  },
  {
    title: '目标端',
    dataIndex: 'target',
    width: 120
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120
  },
  {
    title: '任务版本',
    dataIndex: 'taskVersion',
    width: 120
  },
  {
    title: '任务状态',
    dataIndex: 'taskStatus',
    width: 120
  },
  {
    title: '时延',
    dataIndex: 'latency',
    width: 120
  },
  {
    title: '24小时数据检查有差异',
    dataIndex: 'dataCheckDifference24h',
    width: 120
  },
  {
    title: '最新事件时间',
    dataIndex: 'latestEventTime',
    width: 120,
    slots: {customRender: 'latestEventTime'},
  },
  {
    title: '未处理异常',
    dataIndex: 'unhandledExceptions',
    width: 120
  },
  {
    title: 'DDL',
    dataIndex: 'ddl',
    width: 120
  }
];
/**首页-搜索表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'taskName',
    label: '',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关键字搜索',
      },
    ],
    componentProps: {
      placeholder: '请输入关键字搜索',
    }
  },
];
/**首页-下拉框表单*/
export const selectFormSchema: FormSchema[] = [
  {
    field: 'tree',
    label: '',
    component: 'TreeSelect',
    colProps: { span: 3 },
    componentProps: {
      maxTagCount:1,//最大tag数量
      showArrow: true,//箭头
      treeCheckable: true,
      fieldNames: {
        label: 'treeName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
];
/**首页-重命名表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'taskName',
    label: '任务名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入任务名称',
      },
    ],
    componentProps: {
      placeholder: '请输入任务名称',
    }
  },
];
/**详情页-table列表*/
export const detailColumns: BasicColumn[] = [
  {
    "title": "检查批次",
    "dataIndex": "checkBatch",
    "width": 120
  },
  {
    "title": "统计时间",
    "dataIndex": "statisticalTime",
    "width": 120
  },
  {
    "title": "源端解析数量",
    "dataIndex": "sourceParseCount",
    "width": 120
  },
  {
    "title": "Kafka写入数量",
    "dataIndex": "kafkaWriteCount",
    "width": 120
  },
  {
    "title": "Kafka消费数量",
    "dataIndex": "kafkaConsumeCount",
    "width": 120
  },
  {
    "title": "目标端写入数量",
    "dataIndex": "targetWriteCount",
    "width": 120
  },
  {
    "title": "同步点",
    "dataIndex": "syncPoint",
    "width": 120
  }
];
/**详情页-table列表2*/
export const detailColumns2: BasicColumn[] = [
  {
      "title": "审核时间",
      "dataIndex": "reviewTime",
      "width": 120
  },
  {
      "title": "事件类型",
      "dataIndex": "eventType",
      "width": 120
  },
  {
      "title": "事件名称",
      "dataIndex": "eventName",
      "width": 120
  },
  {
      "title": "涉及topic",
      "dataIndex": "involvedTopic",
      "width": 120
  },
  {
      "title": "涉及表",
      "dataIndex": "involvedTable",
      "width": 120
  },
  {
      "title": "同步点",
      "dataIndex": "syncPoint",
      "width": 120
  }
];
/**详情页-table列表3*/
export const detailColumns3: BasicColumn[] = [
  {
      title: '序号',
      dataIndex: 'indexNumber',
      width: 120
  },
  {
      title: '发生时间',
      dataIndex: 'occurrenceTime',
      width: 120
  },
  {
      title: '数据时间',
      dataIndex: 'dataTime',
      width: 120
  },
  {
      title: '异常类型',
      dataIndex: 'exceptionType',
      width: 120
  },
  {
      title: '涉及topic',
      dataIndex: 'involvedTopic',
      width: 120
  },
  {
      title: '涉及表',
      dataIndex: 'involvedTable',
      width: 120
  },
  {
      title: '涉及操作',
      dataIndex: 'involvedOperation',
      width: 120
  },
  {
      title: '同步点',
      dataIndex: 'syncPoint',
      width: 120
  },
  {
      title: '处理状态',
      dataIndex: 'processingStatus',
      width: 120
  }
];
/**详情页-table列表4*/
export const detailColumns4: BasicColumn[] = [
  {
      title: '事件时间',
      dataIndex: 'eventTime',
      width: 120
  },
  {
      title: '更新时间',
      dataIndex: 'updateTime',
      width: 120
  },
  {
      title: '源端涉及表',
      dataIndex: 'sourceInvolvedTable',
      width: 120
  },
  {
      title: 'DDL产生时任务版本',
      dataIndex: 'taskVersionAtDdl',
      width: 120
  },
  {
      title: 'DDL类型',
      dataIndex: 'ddlType',
      width: 120
  },
  {
      title: '状态',
      dataIndex: 'status',
      width: 120
  },
  {
      title: '处理类型',
      dataIndex: 'processingType',
      width: 120
  }
];
/**详情页-table列表5*/
export const detailColumns5: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'fieldName',
    width: 120,
    slots: {customRender: 'fieldName'}

  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    width: 120,
    slots: {customRender: 'fieldType'}
  },
];
/**详情页-导入 列表6*/
export const detailColumns6: BasicColumn[] = [
  {
    title: '导入时间',
    dataIndex: 'importTime',
    width: 120,
  },
  {
    title: '文件名',
    dataIndex: 'fileName',
    width: 120,
  },
  {
    title: '操作人',
    dataIndex: 'createBy',
    width: 120,
  },
  {
    title: '导入状态',
    dataIndex: 'importState',
    width: 120,
  },
  {
    title: '导入信息',
    dataIndex: 'importInfo',
    width: 120,
  },
];
/**详情页-下拉框表单*/
export const detailFormSchema: FormSchema[] = [
  {
    field: 'eventType',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '事件类型',
      options: [
        {
          label: '系统异常',
          value: '系统异常',
        },
        {
          label: '数据异常',
          value: '数据异常',
        },
        {
          label: '状态切换',
          value: '状态切换',
        },
        {
          label: '策略告警',
          value: '策略告警',
        },
      ],
    },
    colProps: { span:3.5 },
  },
   {
    field: 'eventName',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '事件名称',
      options: [
        {
          label: '源端连接异常',
          value: '源端连接异常',
        },
        {
          label: '日志解析异常',
          value: '日志解析异常',
        },
        {
          label: '内部异常',
          value: '内部异常',
        },
        {
          label: 'kafka写入异常',
          value: 'kafka写入异常',
        },
        {
          label: '数据写入异常',
          value: '数据写入异常',
        },
        {
          label: '数据转换异常',
          value: '数据转换异常',
        },
        {
          label: '未知错误',
          value: '未知错误',
        },
        {
          label: '目标端任务启动',
          value: '目标端任务启动',
        },
        {
          label: '目标端任务暂停',
          value: '目标端任务暂停',
        },
        {
          label: '源端任务启动',
          value: '源端任务启动',
        },
         {
          label: '源端任务暂停',
          value: '源端任务暂停',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: '[startDate, endDate]',
    label: '',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: ['开始日期', '结束日期'],
    },
    colProps: { span:4 },
  },
];
/**详情页-下拉框表单2*/
export const detailFormSchema2: FormSchema[] = [
  {
    field: 'eventType',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '类型',
      options: [
        {
          label: '源端连接异常',
          value: '源端连接异常',
        },
        {
          label: '日志解析异常',
          value: '日志解析异常',
        },
        {
          label: '内部异常',
          value: '内部异常',
        },
        {
          label: 'kafka写入异常',
          value: 'kafka写入异常',
        },
        {
          label: '数据写入异常',
          value: '数据写入异常',
        },
        {
          label: '数据转换异常',
          value: '数据转换异常',
        },
        {
          label: '未知错误',
          value: '未知错误',
        },
        {
          label: '目标端任务启动',
          value: '目标端任务启动',
        },
        {
          label: '目标端任务暂停',
          value: '目标端任务暂停',
        },
        {
          label: '源端任务启动',
          value: '源端任务启动',
        },
         {
          label: '源端任务暂停',
          value: '源端任务暂停',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: 'eventName',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '表',
      options: [
        {
          label: '源端连接异常',
          value: '源端连接异常',
        },
        {
          label: '日志解析异常',
          value: '日志解析异常',
        },
        {
          label: '内部异常',
          value: '内部异常',
        },
        {
          label: 'kafka写入异常',
          value: 'kafka写入异常',
        },
        {
          label: '数据写入异常',
          value: '数据写入异常',
        },
        {
          label: '数据转换异常',
          value: '数据转换异常',
        },
        {
          label: '未知错误',
          value: '未知错误',
        },
        {
          label: '目标端任务启动',
          value: '目标端任务启动',
        },
        {
          label: '目标端任务暂停',
          value: '目标端任务暂停',
        },
        {
          label: '源端任务启动',
          value: '源端任务启动',
        },
         {
          label: '源端任务暂停',
          value: '源端任务暂停',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: 'eventType',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '操作',
      options: [
        {
          label: 'C',
          value: 'C',
        },
        {
          label: 'U',
          value: 'U',
        },
        {
          label: 'D',
          value: 'D',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: '[startDate, endDate]',
    label: '',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: ['开始日期', '结束日期'],
    },
    colProps: { span:6 },
  },
];
/**详情页-下拉框表单3*/
export const detailFormSchema3: FormSchema[] = [
  {
    field: 'sourceTable',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '源端表',
      options: [
        {
          label: '源端连接异常',
          value: '源端连接异常',
        },
        {
          label: '日志解析异常',
          value: '日志解析异常',
        },
        {
          label: '内部异常',
          value: '内部异常',
        },
        {
          label: 'kafka写入异常',
          value: 'kafka写入异常',
        },
        {
          label: '数据写入异常',
          value: '数据写入异常',
        },
        {
          label: '数据转换异常',
          value: '数据转换异常',
        },
        {
          label: '未知错误',
          value: '未知错误',
        },
        {
          label: '目标端任务启动',
          value: '目标端任务启动',
        },
        {
          label: '目标端任务暂停',
          value: '目标端任务暂停',
        },
        {
          label: '源端任务启动',
          value: '源端任务启动',
        },
         {
          label: '源端任务暂停',
          value: '源端任务暂停',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: 'DDLType',
    label: '',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: 'DDL类型',
      options: [
        {
          label: '新增字段',
          value: '新增字段',
        },
        {
          label: '删除字段',
          value: '删除字段',
        },
        {
          label: '字段重命名',
          value: '字段重命名',
        },
        {
          label: '表重命名',
          value: '表重命名',
        },
        {
          label: '删除表',
          value: '删除表',
        },
        {
          label: '新增表',
          value: '新增表',
        },
        {
          label: '清空表',
          value: '清空表',
        },
        {
          label: '字段类型或精度变更',
          value: '字段类型或精度变更',
        },
      ],
    },
    colProps: { span:3.5 },
  },
  {
    field: '[startDate, endDate]',
    label: '',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: ['开始日期', '结束日期'],
    },
    colProps: { span:6 },
  },
];
/**详情页-导入 表单*/
export const importApiFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
    itemProps: {
      extra: '仅支持xls、xlsx格式',
    },
  },
];
/**详情页-DDL详情 表单1*/
export const DDLDetailFormSchema1: FormSchema[] = [
  {
    field: 'DDLTypt',
    label: 'DDL类型:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: '删除字段',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入DDL类型',
    }
  },
  {
    field: 'state',
    label: '状态:',
    labelWidth: 150,
    component: 'Input',
    defaultValue: '未处理',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入状态',
    }
  },
  {
    field: 'sourceType',
    label: '源端类型:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: 'MYSQL',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源端类型',
    }
  },
  {
    field: 'sourceDataTable',
    label: '源端数据表:',
    labelWidth: 150,
    component: 'Input',
    defaultValue:'gxx.gxx3',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源端数据表',
    }
  },
  {
    field: 'sourceField',
    label: '源端字段:',
    labelWidth: 120,
    component: 'Input',
    defaultValue:'T1',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源端字段',
    }
  },
];
/**详情页-DDL详情 表单2*/
export const DDLDetailFormSchema2: FormSchema[] = [
  {
    field: 'produceVersion',
    label: '时间产生时版本:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: 'V3',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入时间产生时版本',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'targetType',
    label: '目标端类型:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: 'MYSQL',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入目标端类型',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'pendingUpdateTable',
    label: '目标端待更新表:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: 'gxx.gxx3',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入目标端待更新表',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'pendingUpdateField',
    label: '目标端待更新字段:',
    labelWidth: 120,
    component: 'Input',
    defaultValue: 'T1',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入目标端待更新字段',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**详情页-DDL详情 表单3*/
export const DDLDetailFormSchema3: FormSchema[] = [
  {
    field: 'taskVersion',
    label: '任务版本:',
    labelWidth: 150,
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入任务版本',
    },
    slot: 'taskVersion',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'targetType',
    label: '目标端类型:',
    labelWidth: 150,
    component: 'Input',
    defaultValue: 'MYSQL',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入目标端类型',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'tableModifyExpectations',
    label: '待更新表修改预期:',
    labelWidth: 150,
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入待更新表修改预期',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldModifyExpectations',
    label: '待更新字段修改预期:',
    labelWidth: 150,
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入待更新字段修改预期',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**详情页-DDL详情 列表*/
export const DDLDetailColumns: BasicColumn[] = [
  {
    title: '处理时间',
    dataIndex: 'handleTime',
    width: 120,
  },
  {
    title: '处理类型',
    dataIndex: 'handleType',
    width: 120,
  },
  {
    title: '处理时任务版本',
    dataIndex: 'handleTaskVersion',
    width: 120,
  },
  {
    title: '处理结果',
    dataIndex: 'handleResult',
    width: 120,
  },
  {
    title: 'SQL语句',
    dataIndex: 'SQL',
    width: 120,
    slots: { customRender: 'SQL' },
  },
  {
    title: '日志',
    dataIndex: 'log',
    width: 120,
    slots: { customRender: 'log' },
  },
];

